@@ -7,7 +7,7 @@ use warnings;
 use Scalar::Util qw/reftype refaddr/;
 use Encode qw/decode encode/;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 our (%HELP, @MAYBE, $caller, $destruct);
 BEGIN {
 	%HELP = (
@@ -48,7 +48,7 @@ sub _maybe {
 
 sub _recurse {
 	my $addr = refaddr $_[0];
-	return exists $_[3]->{$addr} ? $_[3]->{$addr} : do { $_[3]->{$addr} = 1 } && $_[1] eq 'SCALAR' ? $HELP{scalarref}->($_[2], $_[0]) : $_[1] eq 'ARRAY'
+	return defined $_[3]->{$addr} ? $_[0] : do { $_[3]->{$addr} = 1 } && $_[1] eq 'SCALAR' ? $HELP{scalarref}->($_[2], $_[0]) : $_[1] eq 'ARRAY'
 		? $HELP{arrayref}->($_[2], $_[0], $_[3]) && $_[0] : $_[1] eq 'HASH' ? $HELP{hashref}->($_[2], $_[0], $_[3], 1) && $_[0] : $_[0];
 }
 
@@ -66,7 +66,7 @@ Struct::WOP - deeply encode/decode a struct
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
